@@ -1,14 +1,8 @@
-# encoding: utf-8
-
-from collections import namedtuple
 import inspect
 import keyword
-import sys
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
+from collections import namedtuple
+from unittest import mock
 
 try:
     import jedi
@@ -18,13 +12,8 @@ except ImportError:
     has_jedi = False
 
 from bpython import autocomplete
-from bpython._py3compat import py3
-from bpython.test import mock
 
-if py3:
-    glob_function = "glob.iglob"
-else:
-    glob_function = "glob.glob"
+glob_function = "glob.iglob"
 
 
 class TestSafeEval(unittest.TestCase):
@@ -91,9 +80,7 @@ class TestGetCompleter(unittest.TestCase):
 
 
 class TestCumulativeCompleter(unittest.TestCase):
-    def completer(
-        self, matches,
-    ):
+    def completer(self, matches):
         mock_completer = autocomplete.BaseCompletionType()
         mock_completer.matches = mock.Mock(return_value=matches)
         return mock_completer
@@ -116,7 +103,7 @@ class TestCumulativeCompleter(unittest.TestCase):
         a = self.completer(["a"])
         b = self.completer(["b"])
         cumulative = autocomplete.CumulativeCompleter([a, b])
-        self.assertEqual(cumulative.matches(3, "abc"), set(["a", "b"]))
+        self.assertEqual(cumulative.matches(3, "abc"), {"a", "b"})
 
 
 class TestFilenameCompletion(unittest.TestCase):
@@ -177,7 +164,7 @@ class TestFilenameCompletion(unittest.TestCase):
         self.assertEqual(self.completer.format("/hello/there"), "there")
 
 
-class MockNumPy(object):
+class MockNumPy:
     """This is a mock numpy object that raises an error when there is an attempt
     to convert it to a boolean."""
 
@@ -193,7 +180,7 @@ class TestDictKeyCompletion(unittest.TestCase):
         com = autocomplete.DictKeyCompletion()
         local = {"d": {"ab": 1, "cd": 2}}
         self.assertSetEqual(
-            com.matches(2, "d[", locals_=local), set(["'ab']", "'cd']"])
+            com.matches(2, "d[", locals_=local), {"'ab']", "'cd']"}
         )
 
     def test_none_returned_when_eval_error(self):
@@ -217,7 +204,7 @@ class TestDictKeyCompletion(unittest.TestCase):
         self.assertEqual(com.matches(7, "mNumPy[", locals_=local), None)
 
 
-class Foo(object):
+class Foo:
     a = 10
 
     def __init__(self):
@@ -227,28 +214,13 @@ class Foo(object):
         pass
 
 
-class OldStyleFoo:
-    a = 10
-
-    def __init__(self):
-        self.b = 20
-
-    def method(self, x):
-        pass
-
-
-skip_old_style = unittest.skipIf(
-    py3, "In Python 3 there are no old style classes"
-)
-
-
 class Properties(Foo):
     @property
     def asserts_when_called(self):
         raise AssertionError("getter method called")
 
 
-class Slots(object):
+class Slots:
     __slots__ = ["a", "b"]
 
 
@@ -265,56 +237,28 @@ class TestAttrCompletion(unittest.TestCase):
     def test_att_matches_found_on_instance(self):
         self.assertSetEqual(
             self.com.matches(2, "a.", locals_={"a": Foo()}),
-            set(["a.method", "a.a", "a.b"]),
-        )
-
-    @skip_old_style
-    def test_att_matches_found_on_old_style_instance(self):
-        self.assertSetEqual(
-            self.com.matches(2, "a.", locals_={"a": OldStyleFoo()}),
-            set(["a.method", "a.a", "a.b"]),
-        )
-        self.assertIn(
-            u"a.__dict__",
-            self.com.matches(4, "a.__", locals_={"a": OldStyleFoo()}),
-        )
-
-    @skip_old_style
-    def test_att_matches_found_on_old_style_class_object(self):
-        self.assertIn(
-            u"A.__dict__",
-            self.com.matches(4, "A.__", locals_={"A": OldStyleFoo}),
-        )
-
-    @skip_old_style
-    def test_issue536(self):
-        class OldStyleWithBrokenGetAttr:
-            def __getattr__(self, attr):
-                raise Exception()
-
-        locals_ = {"a": OldStyleWithBrokenGetAttr()}
-        self.assertIn(
-            u"a.__module__", self.com.matches(4, "a.__", locals_=locals_)
+            {"a.method", "a.a", "a.b"},
         )
 
     def test_descriptor_attributes_not_run(self):
         com = autocomplete.AttrCompletion()
         self.assertSetEqual(
             com.matches(2, "a.", locals_={"a": Properties()}),
-            set(["a.b", "a.a", "a.method", "a.asserts_when_called"]),
+            {"a.b", "a.a", "a.method", "a.asserts_when_called"},
         )
 
     def test_custom_get_attribute_not_invoked(self):
         com = autocomplete.AttrCompletion()
         self.assertSetEqual(
             com.matches(2, "a.", locals_={"a": OverriddenGetattribute()}),
-            set(["a.b", "a.a", "a.method"]),
+            {"a.b", "a.a", "a.method"},
         )
 
     def test_slots_not_crash(self):
         com = autocomplete.AttrCompletion()
         self.assertSetEqual(
-            com.matches(2, "A.", locals_={"A": Slots}), set(["A.b", "A.a"]),
+            com.matches(2, "A.", locals_={"A": Slots}),
+            {"A.b", "A.a"},
         )
 
 
@@ -326,18 +270,11 @@ class TestExpressionAttributeCompletion(unittest.TestCase):
     def test_att_matches_found_on_instance(self):
         self.assertSetEqual(
             self.com.matches(5, "a[0].", locals_={"a": [Foo()]}),
-            set(["method", "a", "b"]),
-        )
-
-    @skip_old_style
-    def test_att_matches_found_on_old_style_instance(self):
-        self.assertSetEqual(
-            self.com.matches(5, "a[0].", locals_={"a": [OldStyleFoo()]}),
-            set(["method", "a", "b"]),
+            {"method", "a", "b"},
         )
 
     def test_other_getitem_methods_not_called(self):
-        class FakeList(object):
+        class FakeList:
             def __getitem__(inner_self, i):
                 self.fail("possibly side-effecting __getitem_ method called")
 
@@ -346,7 +283,7 @@ class TestExpressionAttributeCompletion(unittest.TestCase):
     def test_tuples_complete(self):
         self.assertSetEqual(
             self.com.matches(5, "a[0].", locals_={"a": (Foo(),)}),
-            set(["method", "a", "b"]),
+            {"method", "a", "b"},
         )
 
     @unittest.skip("TODO, subclasses do not complete yet")
@@ -356,7 +293,7 @@ class TestExpressionAttributeCompletion(unittest.TestCase):
 
         self.assertSetEqual(
             self.com.matches(5, "a[0].", locals_={"a": ListSubclass([Foo()])}),
-            set(["method", "a", "b"]),
+            {"method", "a", "b"},
         )
 
     def test_getitem_not_called_in_list_subclasses_overriding_getitem(self):
@@ -369,13 +306,13 @@ class TestExpressionAttributeCompletion(unittest.TestCase):
     def test_literals_complete(self):
         self.assertSetEqual(
             self.com.matches(10, "[a][0][0].", locals_={"a": (Foo(),)}),
-            set(["method", "a", "b"]),
+            {"method", "a", "b"},
         )
 
     def test_dictionaries_complete(self):
         self.assertSetEqual(
             self.com.matches(7, 'a["b"].', locals_={"a": {"b": Foo()}}),
-            set(["method", "a", "b"]),
+            {"method", "a", "b"},
         )
 
 
@@ -389,7 +326,7 @@ class TestMagicMethodCompletion(unittest.TestCase):
         )
 
 
-Comp = namedtuple("Completion", ["name", "complete"])
+Completion = namedtuple("Completion", ["name", "complete"])
 
 
 @unittest.skipUnless(has_jedi, "jedi required")
@@ -414,7 +351,7 @@ class TestMultilineJediCompletion(unittest.TestCase):
     ):
         with mock.patch("bpython.autocomplete.jedi.Script") as Script:
             script = Script.return_value
-            script.completions.return_value = completions
+            script.complete.return_value = completions
             com = autocomplete.MultilineJediCompletion()
             return com.matches(
                 cursor, line, current_block=block, history=history
@@ -426,7 +363,7 @@ class TestMultilineJediCompletion(unittest.TestCase):
             " a",
             "class Foo:\n a",
             ["adsf"],
-            [Comp("Abc", "bc"), Comp("Cbc", "bc")],
+            [Completion("Abc", "bc"), Completion("Cbc", "bc")],
         )
         self.assertEqual(matches, None)
 
@@ -436,11 +373,10 @@ class TestMultilineJediCompletion(unittest.TestCase):
             " a",
             "class Foo:\n a",
             ["adsf"],
-            [Comp("Abc", "bc"), Comp("ade", "de")],
+            [Completion("Abc", "bc"), Completion("ade", "de")],
         )
-        self.assertSetEqual(matches, set(["ade"]))
+        self.assertSetEqual(matches, {"ade"})
 
-    @unittest.skipUnless(py3, "asyncio required")
     def test_issue_544(self):
         com = autocomplete.MultilineJediCompletion()
         code = "@asyncio.coroutine\ndef"
@@ -458,16 +394,12 @@ class TestGlobalCompletion(unittest.TestCase):
 
         self.assertEqual(
             self.com.matches(8, "function", locals_={"function": function}),
-            set(("function(",)),
+            {"function("},
         )
 
     def test_completions_are_unicode(self):
         for m in self.com.matches(1, "a", locals_={"abc": 10}):
-            self.assertIsInstance(m, type(u""))
-
-    @unittest.skipIf(py3, "in Python 3 invalid identifiers are passed through")
-    def test_ignores_nonascii_encodable(self):
-        self.assertEqual(self.com.matches(3, "abc", locals_={"abcß": 10}), None)
+            self.assertIsInstance(m, str)
 
     def test_mock_kwlist(self):
         with mock.patch.object(keyword, "kwlist", new=["abcd"]):
@@ -483,19 +415,11 @@ class TestParameterNameCompletion(unittest.TestCase):
         def func(apple, apricot, banana, carrot):
             pass
 
-        if py3:
-            argspec = list(inspect.getfullargspec(func))
-        else:
-            argspec = list(inspect.getargspec(func))
-
+        argspec = list(inspect.getfullargspec(func))
         argspec = ["func", argspec, False]
         com = autocomplete.ParameterNameCompletion()
         self.assertSetEqual(
-            com.matches(1, "a", argspec=argspec), set(["apple=", "apricot="])
-        )
-        self.assertSetEqual(
-            com.matches(2, "ba", argspec=argspec), set(["banana="])
-        )
-        self.assertSetEqual(
-            com.matches(3, "car", argspec=argspec), set(["carrot="])
+            com.matches(1, "a", argspec=argspec), {"apple=", "apricot="}
         )
+        self.assertSetEqual(com.matches(2, "ba", argspec=argspec), {"banana="})
+        self.assertSetEqual(com.matches(3, "car", argspec=argspec), {"carrot="})
