@@ -1,18 +1,14 @@
-# encoding: utf-8
-
-import io
-import os
-
-from six.moves import range
+import tempfile
+import unittest
+from pathlib import Path
 
 from bpython.config import getpreferredencoding
 from bpython.history import History
-from bpython.test import unittest
 
 
 class TestHistory(unittest.TestCase):
     def setUp(self):
-        self.history = History("#%d" % x for x in range(1000))
+        self.history = History(f"#{x}" for x in range(1000))
 
     def test_is_at_start(self):
         self.history.first()
@@ -89,10 +85,11 @@ class TestHistory(unittest.TestCase):
 
 class TestHistoryFileAccess(unittest.TestCase):
     def setUp(self):
-        self.filename = "history_temp_file"
+        self.tempdir = tempfile.TemporaryDirectory()
+        self.filename = str(Path(self.tempdir.name) / "history_temp_file")
         self.encoding = getpreferredencoding()
 
-        with io.open(
+        with open(
             self.filename, "w", encoding=self.encoding, errors="ignore"
         ) as f:
             f.write(b"#1\n#2\n".decode())
@@ -114,21 +111,17 @@ class TestHistoryFileAccess(unittest.TestCase):
 
     def test_save(self):
         history = History()
-        history.entries = []
-        for line in ["#1", "#2", "#3", "#4"]:
+        for line in ("#1", "#2", "#3", "#4"):
             history.append_to(history.entries, line)
 
         # save only last 2 lines
         history.save(self.filename, self.encoding, lines=2)
 
-        # empty the list of entries and load again from the file
-        history.entries = [""]
+        # load again from the file
+        history = History()
         history.load(self.filename, self.encoding)
 
         self.assertEqual(history.entries, ["#3", "#4"])
 
     def tearDown(self):
-        try:
-            os.remove(self.filename)
-        except OSError:
-            pass
+        self.tempdir = None
